import subprocess
import sys
import win32serviceutil

def upgrade_and_restart_service(service_name):
    try:
        # Upgrade axya-whisper package using pip
        subprocess.check_call([sys.executable, "-m", "pip", "install", "--upgrade", "axya-whisper"])

        # Check if the package was upgraded
        # You might need to replace 'axya-whisper' with the actual package name
        package_version = subprocess.check_output([sys.executable, "-m", "pip", "show", "axya-whisper"])
        package_version = package_version.decode("utf-8")
        current_version = None

        for line in package_version.split('\n'):
            if line.startswith('Version:'):
                current_version = line.split(' ')[-1].strip()
                break

        if current_version:
            print(f"axya-whisper upgraded to version {current_version}")
            restart_service(service_name)
        else:
            print("axya-whisper is already up-to-date")

    except subprocess.CalledProcessError as e:
        print(f"Error upgrading axya-whisper: {e}")

def restart_service(service_name):
    try:
        win32serviceutil.RestartService(service_name)
        print(f"The service '{service_name}' has been restarted.")
    except Exception as e:
        print(f"Error restarting service: {e}")




import os
import sys

def check_environment_variables():
    required_variables = [
        'GENIUS_API_URL',
        'GENIUS_API_LOGIN',
        'GENIUS_API_PASSWORD',
        'GENIUS_API_COMPANY_CODE',
        'AXYA_API_URL',
        'AXYA_API_TOKEN',
    ]
    is_missing = False
    for variable in required_variables:
        if not os.environ.get(variable):
            print(f"Environment variable {variable} is not set. Please set it.")
            is_missing = True

    if is_missing:
        try:
            sys.exit(1)
        except SystemExit as e:
            sys.exit(e.code)

if __name__ == '__main__':
    check_environment_variables()
    print("All required environment variables are set.")



import os 

VERIFY_SSL = False
SERVICE_CACHE_KEY = "GENIUS_API_TOKEN"
GENIUS_API_URL = os.environ.get('GENIUS_API_URL') 
GENIUS_API_LOGIN = os.environ.get('GENIUS_API_LOGIN')
GENIUS_API_PASSWORD = os.environ.get('GENIUS_API_PASSWORD')
GENIUS_API_COMPANY_CODE = os.environ.get('GENIUS_API_COMPANY_CODE')
AXYA_API_URL = os.environ.get('AXYA_API_URL')
AXYA_API_TOKEN = os.environ.get('AXYA_API_TOKEN')


GENIUS_PO_SENT_TYPE_ID = os.environ.get('GENIUS_PO_SENT_STATUS_ID', 11)


class GeniusERPPurchaseOrderMapping:
    name = "Code"
    vendor_id = "PaidToVendorCode"
    updated_date = "LastUpdate"
    delivery_date = "DeliveryDate"
    revision_date = "RevisionDate"
    created_at = "PurchaseDate"
    note = "QuickNote"
    status = "PurchaseOrderTypeId"


class GeniusERPPurchaseOrderLineItemMapping:
    name = "ItemCode"
    price = "Price"
    quantity = "QtyOrdered"
    delivery_date = "DateDelivery"
    updated_delivery_date = "VendorSuggestedDeliveryDate"
    confirmation_date = "VendorConfirmationDate"
    created_at = "PurchaseDate"
    description = "FullSearch"


import logging
from datetime import datetime

logger = logging.getLogger("axyawhisper.models")


class GeniusERPConfigurationResponse:
    def __init__(self, response_data):
        self.id = response_data.get('id')
        self.created_at = response_data.get('created_at')
        self.updated_at = response_data.get('updated_at')
        self.suppliers_filter = response_data.get('suppliers_filter')
        self.auto_send_po = response_data.get('auto_send_po')
        self.auto_archive_purchase_order = response_data.get('auto_archive_purchase_order')
        self.fetch_sent_purchase_orders_enabled = response_data.get('fetch_sent_purchase_orders_enabled')
        self.fetch_po_statuses_enabled = response_data.get('fetch_po_statuses_enabled')
        self.fetch_po_buyers_enabled = response_data.get('fetch_po_buyers_enabled')
        self.auto_sync_updated_delivery_dates = response_data.get('auto_sync_updated_delivery_dates')
        self.auto_sync_line_item_status = response_data.get('auto_sync_line_item_status')
        self.created_by = response_data.get('created_by')
        self.updated_by = response_data.get('updated_by')
        self.company = response_data.get('company')

        self.last_time_po_sync = self.format_datetime(response_data.get('last_time_po_sync'))
        self.last_time_suppliers_sync = self.format_datetime(response_data.get('last_time_suppliers_sync'))
        self.last_time_buyers_sync = self.format_datetime(response_data.get('last_time_buyers_sync'))

    def format_datetime(self, date_str):
        print(date_str)
        if date_str:
            try:
                # Attempt to parse with microseconds and timezone
                dt = datetime.strptime(date_str, '%Y-%m-%dT%H:%M:%S.%f')
            except ValueError:
                try:
                    # Attempt to parse without microseconds and timezone
                    dt = datetime.strptime(date_str, '%Y-%m-%dT%H:%M:%S')
                except ValueError:
                    # If parsing fails, return None
                    logger.info("ValueError: {date_str}")
                    return None
            print("dt:", dt.strftime("%Y-%m-%dT%H:%M:%S.%f%z"))
            return dt.strftime("%Y-%m-%dT%H:%M:%S.%f%z")

        return None


import subprocess
import sys
from setuptools import setup, find_packages
from setuptools.command.install import install

class CheckEnvVariables(install):
    def run(self):
        # Run the environment variable check before installing
        subprocess.check_call([sys.executable, 'axya_whisper/check.py'])
        super().run()

setup(
    name='axya-whisper',
    version='0.1.29',
    packages=find_packages(),
    package_data={'': ['assets/axya.ico']},
    install_requires=[
        'pywin32',
        'keyring',
        'requests',
        'pystray',
        'Pillow'
    ],
    cmdclass={'install': CheckEnvVariables},
    entry_points={
        'console_scripts': [
            'axya-whisper-windows-service=axya_whisper.__main__:main',
        ],
    },
    python_requires='>=3.6',
)


import os
import sys
import time
import win32serviceutil
import win32service
import win32event

from .service import HelloWindowService

def main():
    win32serviceutil.HandleCommandLine(HelloWindowService)